==> skimage_0.9.3.orig.tar.gz: scikit-image-0.9.3/skimage/transform/__init__.py <==
from ._hough_transform import (hough_circle, hough_ellipse, hough_line,
                               probabilistic_hough_line)
from .hough_transform import hough_line_peaks
from .radon_transform import radon, iradon, iradon_sart
from .finite_radon_transform import frt2, ifrt2
from .integral import integral_image, integrate
from ._geometric import (warp, warp_coords, estimate_transform,
                         SimilarityTransform, AffineTransform,
                         ProjectiveTransform, PolynomialTransform,
                         PiecewiseAffineTransform)
from ._warps import swirl, resize, rotate, rescale, downscale_local_mean
from .pyramids import (pyramid_reduce, pyramid_expand,
                       pyramid_gaussian, pyramid_laplacian)


__all__ = ['hough_circle',
           'hough_ellipse',
           'hough_line',
           'probabilistic_hough_line',
           'probabilistic_hough',
           'hough_peaks',
           'hough_line_peaks',
           'radon',
           'iradon',
           'iradon_sart',
           'frt2',
           'ifrt2',
           'integral_image',
           'integrate',
           'warp',
           'warp_coords',
           'estimate_transform',
           'SimilarityTransform',
           'AffineTransform',
           'ProjectiveTransform',
           'PolynomialTransform',
           'PiecewiseAffineTransform',
           'swirl',
           'resize',
           'rotate',
           'rescale',
           'downscale_local_mean',
           'pyramid_reduce',
           'pyramid_expand',
           'pyramid_gaussian',
           'pyramid_laplacian']

==> skimage_0.10.1.orig.tar.gz: scikit-image-0.10.1/skimage/transform/__init__.py <==
from ._hough_transform import (hough_ellipse, hough_line,
                               probabilistic_hough_line)
from .hough_transform import hough_circle, hough_line_peaks
from .radon_transform import radon, iradon, iradon_sart
from .finite_radon_transform import frt2, ifrt2
from .integral import integral_image, integrate
from ._geometric import (warp, warp_coords, estimate_transform,
                         matrix_transform,
                         SimilarityTransform, AffineTransform,
                         ProjectiveTransform, PolynomialTransform,
                         PiecewiseAffineTransform)
from ._warps import swirl, resize, rotate, rescale, downscale_local_mean
from .pyramids import (pyramid_reduce, pyramid_expand,
                       pyramid_gaussian, pyramid_laplacian)


__all__ = ['hough_circle',
           'hough_ellipse',
           'hough_line',
           'probabilistic_hough_line',
           'probabilistic_hough',
           'hough_peaks',
           'hough_line_peaks',
           'radon',
           'iradon',
           'iradon_sart',
           'frt2',
           'ifrt2',
           'integral_image',
           'integrate',
           'warp',
           'warp_coords',
           'estimate_transform',
           'matrix_transform',
           'SimilarityTransform',
           'AffineTransform',
           'ProjectiveTransform',
           'PolynomialTransform',
           'PiecewiseAffineTransform',
           'swirl',
           'resize',
           'rotate',
           'rescale',
           'downscale_local_mean',
           'pyramid_reduce',
           'pyramid_expand',
           'pyramid_gaussian',
           'pyramid_laplacian']
